@@ -1,26 +1,17 @@
 """Voice Assistant interface base classes."""
 
-from abc import ABC, abstractmethod
+import abc
 
 
-class BaseInterface(ABC):
-    """Base Voice Assistant interface."""
-
-    @abstractmethod
-    def run(self) -> None:
-        """Run interface."""
-        pass
-
-
-class InterfaceIO(BaseInterface):
+class InterfaceIO(abc.ABC):
     """Voice Assistant user interface with support of input/output."""
 
-    @abstractmethod
+    @abc.abstractmethod
     def input(self) -> str:
         """Get input from user."""
-        return ""
+        raise NotImplementedError
 
-    @abstractmethod
+    @abc.abstractmethod
     def output(self, text: str, cache: bool = False) -> None:
         """Provide output to user as `text`."""
-        pass
+        raise NotImplementedError
