@@ -11,10 +11,13 @@ from tenacity import retry, retry_if_not_exception_type, stop_after_attempt, wai
 from voiceassistant.exceptions import ActionError, SkillError
 from voiceassistant.interfaces.base import InterfaceIO
 from voiceassistant.utils.datastruct import DottedDict
+from voiceassistant.utils.log import get_logger
 
 if TYPE_CHECKING:
     from voiceassistant.core import VoiceAssistant
 
+_LOGGER = get_logger(__name__)
+
 
 @dataclass
 class Routine:
@@ -31,7 +34,7 @@ class Routine:
 class Skill(Routine):
     """Skill class."""
 
-    def run(self, vass: VoiceAssistant, entities: DottedDict, interface: InterfaceIO,) -> None:
+    def run(self, vass: VoiceAssistant, entities: DottedDict, interface: InterfaceIO) -> None:
         """Call skill function with arguments that it accepts."""
         possible_kwargs = {
             "vass": vass,
@@ -44,7 +47,7 @@ class Skill(Routine):
             raise SkillError(f"Skill function {self.name} has unrecognized argument: {e}")
 
         to_print = "\n".join((f"name:     {self.name}", f"entities: {entities}"))
-        print(f"\n\033[92m{to_print}\033[0m")
+        _LOGGER.info(f"Intent recognized\n\033[92m{to_print}\033[0m")
 
         self.func(**kwargs)
 
@@ -59,7 +62,7 @@ class Action(Routine):
         reraise=True,
     )
     def run(
-        self, vass: VoiceAssistant, entities: DottedDict, interface: InterfaceIO, **kwargs: Any,
+        self, vass: VoiceAssistant, entities: DottedDict, interface: InterfaceIO, **kwargs: Any
     ) -> None:
         """Call action function with arguments that it accepts."""
         possible_kwargs = {
